summaryrefslogtreecommitdiffhomepage
path: root/dev/boot/src
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@nekernel.org>2025-04-01 08:39:18 +0200
committerGitHub <noreply@github.com>2025-04-01 08:39:18 +0200
commitf88f6074479c627529559f690bf836960d5a6378 (patch)
treea1acef0bd6286f03197c0e1839e8d41ac5e5538f /dev/boot/src
parent6849e75f2e95e88b43e2f8804abf1b862e3981cb (diff)
parent2a7a9825fd275d6d999b94614fe87c1d705c7f8f (diff)
Merge pull request #4 from amlel-el-mahrouss/dev
pr/general: mostly minor patches.
Diffstat (limited to 'dev/boot/src')
-rw-r--r--dev/boot/src/BootFileReader.cc2
-rw-r--r--dev/boot/src/BootThread.cc2
-rw-r--r--dev/boot/src/HEL/AMD64/BootEFI.cc10
-rw-r--r--dev/boot/src/HEL/ARM64/BootEFI.cc10
4 files changed, 12 insertions, 12 deletions
diff --git a/dev/boot/src/BootFileReader.cc b/dev/boot/src/BootFileReader.cc
index 7fed58f0..1236b7f0 100644
--- a/dev/boot/src/BootFileReader.cc
+++ b/dev/boot/src/BootFileReader.cc
@@ -13,7 +13,7 @@
#include <BootKit/BootKit.h>
#include <FirmwareKit/Handover.h>
#include <FirmwareKit/EFI/API.h>
-#include <modules/CoreGfx/TextMgr.h>
+#include <modules/CoreGfx/TextGfx.h>
/// @file BootFileReader
/// @brief Bootloader File reader.
diff --git a/dev/boot/src/BootThread.cc b/dev/boot/src/BootThread.cc
index 4cd2c466..3341601a 100644
--- a/dev/boot/src/BootThread.cc
+++ b/dev/boot/src/BootThread.cc
@@ -13,7 +13,7 @@
#include <KernelKit/PE.h>
#include <KernelKit/MSDOS.h>
#include <CFKit/Utils.h>
-#include <modules/CoreGfx/TextMgr.h>
+#include <modules/CoreGfx/TextGfx.h>
/// @brief External boot services symbol.
EXTERN EfiBootServices* BS;
diff --git a/dev/boot/src/HEL/AMD64/BootEFI.cc b/dev/boot/src/HEL/AMD64/BootEFI.cc
index 5f89aae6..076055b9 100644
--- a/dev/boot/src/HEL/AMD64/BootEFI.cc
+++ b/dev/boot/src/HEL/AMD64/BootEFI.cc
@@ -5,8 +5,8 @@
------------------------------------------- */
#include <BootKit/BootKit.h>
-#include <modules/CoreGfx/FBMgr.h>
-#include <modules/CoreGfx/TextMgr.h>
+#include <modules/CoreGfx/CoreGfx.h>
+#include <modules/CoreGfx/TextGfx.h>
#include <FirmwareKit/EFI.h>
#include <FirmwareKit/EFI/API.h>
#include <FirmwareKit/Handover.h>
@@ -16,7 +16,7 @@
#include <NewKit/Macros.h>
#include <NewKit/Ref.h>
#include <BootKit/BootThread.h>
-#include <modules/CoreGfx/FBMgr.h>
+#include <modules/CoreGfx/CoreGfx.h>
// Makes the compiler shut up.
#ifndef kMachineModel
@@ -78,11 +78,11 @@ STATIC Bool boot_init_fb() noexcept
EfiGUID kEfiGlobalNamespaceVarGUID = {
0x8BE4DF61, 0x93CA, 0x11D2, {0xAA, 0x0D, 0x00, 0xE0, 0x98, 0x03, 0x2B, 0x8C}};
/// @brief Main EFI entrypoint.
/// @param image_handle Handle of this image.
/// @param sys_table The system table of it.
/// @return nothing, never returns.
-EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr image_handle,
+EFI_EXTERN_C EFI_API Int32 ModuleMain(EfiHandlePtr image_handle,
EfiSystemTable* sys_table)
{
InitEFI(sys_table); ///! Init the EFI library.
@@ -78,11 +78,11 @@ STATIC Bool boot_init_fb() noexcept
EfiGUID kEfiGlobalNamespaceVarGUID = {
0x8BE4DF61, 0x93CA, 0x11D2, {0xAA, 0x0D, 0x00, 0xE0, 0x98, 0x03, 0x2B, 0x8C}};
-/// @brief Main EFI entrypoint.
+/// @brief ModuleMain EFI entrypoint.
/// @param image_handle Handle of this image.
/// @param sys_table The system table of it.
diff --git a/dev/boot/src/HEL/ARM64/BootEFI.cc b/dev/boot/src/HEL/ARM64/BootEFI.cc
index 6839c2ec..adce693e 100644
--- a/dev/boot/src/HEL/ARM64/BootEFI.cc
+++ b/dev/boot/src/HEL/ARM64/BootEFI.cc
@@ -5,8 +5,8 @@
------------------------------------------- */
#include <BootKit/BootKit.h>
-#include <modules/CoreGfx/FBMgr.h>
-#include <modules/CoreGfx/TextMgr.h>
+#include <modules/CoreGfx/CoreGfx.h>
+#include <modules/CoreGfx/TextGfx.h>
#include <FirmwareKit/EFI.h>
#include <FirmwareKit/EFI/API.h>
#include <FirmwareKit/Handover.h>
@@ -16,7 +16,7 @@
#include <NewKit/Macros.h>
#include <NewKit/Ref.h>
#include <BootKit/BootThread.h>
-#include <modules/CoreGfx/FBMgr.h>
+#include <modules/CoreGfx/CoreGfx.h>
// Makes the compiler shut up.
#ifndef kMachineModel
@@ -74,11 +74,11 @@ STATIC Bool boot_init_fb() noexcept
EXTERN EfiBootServices* BS;
/// @brief Main EFI entrypoint.
/// @param image_handle Handle of this image.
/// @param sys_table The system table of it.
/// @return nothing, never returns.
-EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr image_handle,
+EFI_EXTERN_C EFI_API Int32 ModuleMain(EfiHandlePtr image_handle,
EfiSystemTable* sys_table)
{
InitEFI(sys_table); ///! Init the EFI library.
@@ -74,11 +74,11 @@ STATIC Bool boot_init_fb() noexcept
EXTERN EfiBootServices* BS;
-/// @brief Main EFI entrypoint.
+/// @brief ModuleMain EFI entrypoint.
/// @param image_handle Handle of this image.
/// @param sys_table The system table of it.